# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trade/api/trade.service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nf.pb.core.api import common_pb2 as core_dot_api_dot_common__pb2
from nf.pb.core.api import account_pb2 as core_dot_api_dot_account__pb2
from nf.pb.core.api.report import service_pb2 as core_dot_api_dot_report_dot_service__pb2
from nf.pb.data.api import data_pb2 as data_dot_api_dot_data__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nf.pb.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='trade/api/trade.service.proto',
  package='trade.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1dtrade/api/trade.service.proto\x12\ttrade.api\x1a\x15\x63ore/api/common.proto\x1a\x16\x63ore/api/account.proto\x1a\x1d\x63ore/api/report.service.proto\x1a\x13\x64\x61ta/api/data.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\xbf\x01\n\x0cGetOrdersReq\x12-\n\x06\x63ommon\x18\x06 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x0f\n\x07symbols\x18\x04 \x03(\t\x12\x12\n\ncl_ord_ids\x18\x05 \x03(\t\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\x12\x10\n\x08\x65xchange\x18\x08 \x01(\t\"\xb3\x01\n\x11GetOrdersPagedReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\t\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12\x12\n\ncl_ord_ids\x18\x04 \x03(\t\x12\x13\n\x0bstrategy_id\x18\x05 \x01(\t\x12-\n\x06\x63ommon\x18\x06 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"\xa4\x01\n\x16GetUnfinishedOrdersReq\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\"\xac\x01\n\x1eGetIntradayUnfinishedOrdersReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\"\xb6\x01\n\x14GetIntradayOrdersReq\x12-\n\x06\x63ommon\x18\x05 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x12\n\ncl_ord_ids\x18\x04 \x03(\t\x12\x13\n\x0bstrategy_id\x18\x06 \x01(\t\x12\x10\n\x08\x65xchange\x18\x07 \x01(\t\"\xc2\x01\n\x0eGetExecrptsReq\x12-\n\x06\x63ommon\x18\x06 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x12\n\naccount_id\x18\x02 \x01(\t\x12\x11\n\tcl_ord_id\x18\x03 \x01(\t\x12\x11\n\texec_type\x18\x04 \x01(\x05\x12\x13\n\x0bstrategy_id\x18\x05 \x01(\t\x12\x10\n\x08\x65xchange\x18\x07 \x01(\t\"\xb7\x01\n\x16GetIntradayExecrptsReq\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\x11\n\texec_type\x18\x03 \x01(\x05\x12\x13\n\x0bstrategy_id\x18\x05 \x01(\t\x12\x10\n\x08\x65xchange\x18\x06 \x01(\t\"\x96\x01\n\nGetCashReq\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\x12\x12\n\naccount_id\x18\x06 \x01(\t\"\xe6\x01\n\x0fGetPositionsReq\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\x12\x12\n\naccount_id\x18\x06 \x01(\t\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\x12\x10\n\x08\x65xchange\x18\x08 \x01(\t\x12\x10\n\x08\x63urrency\x18\t \x01(\t\"\x97\x01\n\rGetAccountReq\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12 \n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x10.core.api.Filter\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\"_\n\nSymbolsReq\x12-\n\x06\x63ommon\x18\x03 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\"_\n\rPlaceOrderReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x1f\n\x06orders\x18\x02 \x03(\x0b\x32\x0f.core.api.Order\"a\n\nAlertMeReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0bstrategy_id\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x87\x01\n\x0e\x43\x61ncelOrderReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x1f\n\x06orders\x18\x02 \x03(\x0b\x32\x0f.core.api.Order\x12\x13\n\x0bstrategy_id\x18\x03 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\"\xb5\x01\n\x12SearchCoinPairsReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0e\n\x06symbol\x18\x02 \x03(\t\x12\'\n\x07subject\x18\x03 \x01(\x0e\x32\x16.core.api.SecurityType\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x05 \x01(\t\x12\x17\n\x0f\x63ontract_period\x18\x06 \x01(\t\"\xaf\x01\n\x0fTargetSymbolReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0e\n\x06market\x18\x02 \x01(\t\x12\r\n\x05\x66ront\x18\x03 \x01(\t\x12\x0c\n\x04rear\x18\x04 \x01(\t\x12\'\n\x07subject\x18\x05 \x01(\x0e\x32\x16.core.api.SecurityType\x12\x17\n\x0f\x63ontract_period\x18\x06 \x01(\t\"q\n\x10TradingSymbolReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0e\n\x06market\x18\x02 \x01(\t\x12\x0e\n\x06\x63oin_a\x18\x03 \x01(\t\x12\x0e\n\x06\x63oin_b\x18\x04 \x01(\t\"?\n\x12SearchCoinPairsRsp\x12)\n\x0bsymbolinfos\x18\x01 \x03(\x0b\x32\x14.core.api.SymbolInfo\"i\n\x0f\x45xchangeRateReq\x12\x10\n\x08\x63urrency\x18\x01 \x03(\t\x12\x15\n\rfrom_currency\x18\x02 \x01(\t\x12-\n\x06\x63ommon\x18\x03 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"M\n\x0c\x43ommisionReq\x12\x0e\n\x06symbol\x18\x01 \x03(\t\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"N\n\x0b\x43urrencyReq\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\"\x1c\n\rGetMarketsReq\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\"@\n\x0f\x41llRearCoinsReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"\x8d\x01\n\x13\x41llSymbolsByRearReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0c\n\x04rear\x18\x02 \x01(\t\x12\'\n\x07subject\x18\x03 \x01(\x0e\x32\x16.core.api.SecurityType\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\"\x9e\x01\n\x15\x41llMarketsBySymbolReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\r\n\x05\x66ront\x18\x02 \x01(\t\x12\x0c\n\x04rear\x18\x03 \x01(\t\x12\'\n\x07subject\x18\x04 \x01(\x0e\x32\x16.core.api.SecurityType\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\"\x8c\x01\n\x15SymbolsByFrontRearReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\r\n\x05\x66ront\x18\x02 \x01(\t\x12\x0c\n\x04rear\x18\x03 \x01(\t\x12\'\n\x07subject\x18\x04 \x01(\x0e\x32\x16.core.api.SecurityType\"R\n\x11ValidRearCoinsReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0e\n\x06market\x18\x02 \x01(\t\"k\n\x14MarketsByStrategyReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0bstrategy_id\x18\x02 \x01(\t\x12\x0f\n\x07markets\x18\x03 \x03(\t\"Y\n\x17StrategyTemplateListReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"Y\n\x13StrategyTemplateReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0btemplate_id\x18\x02 \x01(\t\"z\n\x0fGetOrderInfoReq\x12-\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x12\n\napi_secret\x18\x03 \x01(\t\x12\x13\n\x0b\x63l_order_id\x18\x04 \x01(\t\"R\n\x08StatsReq\x12\x17\n\x0fUnderlying_base\x18\x01 \x01(\t\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"J\n\tSymbolReq\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"5\n\x10GetMarkPriceResp\x12!\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x13.data.api.MarkPrice\"b\n\nIndexPrice\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x35\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"8\n\x11GetIndexPriceResp\x12#\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x15.trade.api.IndexPrice\"_\n\nSettlement\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x32\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\"f\n\x10GetSettlementReq\x12#\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x15.trade.api.Settlement\x12-\n\x06\x63ommon\x18\x02 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\"\x1f\n\x0f\x46undingRateResp\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"\xb5\x01\n\x12GetMarginAssetsReq\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x03 \x01(\t\x12\x12\n\napi_secret\x18\x04 \x01(\t\x12-\n\x06\x63ommon\x18\x05 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0bstrategy_id\x18\x06 \x01(\t\x12\x12\n\naccount_id\x18\x07 \x01(\t\"\xba\x01\n\nSetModeReq\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\r\n\x05model\x18\x03 \x01(\x05\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\x12-\n\x06\x63ommon\x18\x06 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\x12\x12\n\naccount_id\x18\x08 \x01(\t\"#\n\x04Stat\x12\x0b\n\x03ret\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\t\")\n\x08StatResp\x12\x1d\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x0f.trade.api.Stat\"\xc1\x01\n\x0eSetLeverageReq\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08leverage\x18\x03 \x01(\x01\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\x12-\n\x06\x63ommon\x18\x06 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\x12\x12\n\naccount_id\x18\x08 \x01(\t\"\xbd\x01\n\x0cSetMarginReq\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x01\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x12\n\napi_secret\x18\x05 \x01(\t\x12-\n\x06\x63ommon\x18\x06 \x01(\x0b\x32\x1d.core.api.RequestCommonParams\x12\x13\n\x0bstrategy_id\x18\x07 \x01(\t\x12\x12\n\naccount_id\x18\x08 \x01(\t\"[\n\x0bSetAlertReq\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x01\x12-\n\x06\x63ommon\x18\x03 \x01(\x0b\x32\x1d.core.api.RequestCommonParams2\xa1\x10\n\x0cTradeService\x12_\n\nGetMarkets\x12\x18.trade.api.GetMarketsReq\x1a\x11.core.api.Markets\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v3/account-trade/markets:\x01*\x12^\n\x0bPlaceOrders\x12\x18.trade.api.PlaceOrderReq\x1a\x10.core.api.Orders\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v3/account-trade/orders:\x01*\x12^\n\x07\x41lertMe\x12\x15.trade.api.AlertMeReq\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v3/account-trade/alertme:\x01*\x12m\n\x0c\x43\x61ncelOrders\x12\x19.trade.api.CancelOrderReq\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02$\"\x1f/v3/account-trade/cancel-orders:\x01*\x12q\n\x0cGetPositions\x12\x1a.trade.api.GetPositionsReq\x1a\x13.core.api.Positions\"0\x82\xd3\xe4\x93\x02*\x12(/v3/account-trade/positions/{account_id}\x12\x65\n\tGetOrders\x12\x17.trade.api.GetOrdersReq\x1a\x10.core.api.Orders\"-\x82\xd3\xe4\x93\x02\'\x12%/v3/account-trade/orders/{account_id}\x12o\n\x0eGetOrdersPaged\x12\x1c.trade.api.GetOrdersPagedReq\x1a\x15.core.api.OrdersPaged\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v3/account-trade/orders-page:\x01*\x12~\n\x11GetIntradayOrders\x12\x1f.trade.api.GetIntradayOrdersReq\x1a\x10.core.api.Orders\"6\x82\xd3\xe4\x93\x02\x30\x12./v3/account-trade/intraday-orders/{account_id}\x12\x84\x01\n\x13GetUnfinishedOrders\x12!.trade.api.GetUnfinishedOrdersReq\x1a\x10.core.api.Orders\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v3/account-trade/unfinished-orders/{account_id}\x12\x9d\x01\n\x1bGetIntradayUnfinishedOrders\x12).trade.api.GetIntradayUnfinishedOrdersReq\x1a\x10.core.api.Orders\"A\x82\xd3\xe4\x93\x02;\x12\x39/v3/account-trade/intraday-unfinished-orders/{account_id}\x12\xf3\x01\n\x0bGetExecrpts\x12\x19.trade.api.GetExecrptsReq\x1a\x12.core.api.ExecRpts\"\xb4\x01\x82\xd3\xe4\x93\x02\xad\x01\x12\'/v3/account-trade/execrpts/{account_id}ZB\x12@/v3/account-trade/execrpts/{account_id}/belong-order/{cl_ord_id}Z>\x12</v3/account-trade/execrpts/{account_id}/exectype/{exec_type}\x12\x86\x01\n\x13GetIntradayExecrpts\x12!.trade.api.GetIntradayExecrptsReq\x1a\x12.core.api.ExecRpts\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v3/account-trade/intraday-execrpts/{account_id}\x12s\n\x14GetAccountListFromTc\x12\x18.trade.api.GetAccountReq\x1a\x12.core.api.Accounts\"-\x82\xd3\xe4\x93\x02\'\x12%/v3/account-trade/account-list-fromtc\x12o\n\x0cGetOrderInfo\x12\x1a.trade.api.GetOrderInfoReq\x1a\x0f.core.api.Order\"2\x82\xd3\xe4\x93\x02,\x12*/v3/account-trade/order-info/{cl_order_id}\x12\\\n\x07SetMode\x12\x15.trade.api.SetModeReq\x1a\x13.trade.api.StatResp\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v3/account-trade/set-mode:\x01*\x12h\n\x0bSetLeverage\x12\x19.trade.api.SetLeverageReq\x1a\x13.trade.api.StatResp\")\x82\xd3\xe4\x93\x02#\"\x1e/v3/account-trade/set-leverage:\x01*\x12\x62\n\tAddMargin\x12\x17.trade.api.SetMarginReq\x1a\x13.trade.api.StatResp\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v3/account-trade/add-margin:\x01*2\xd8\x15\n\x10TradeDataService\x12p\n\x12GetInstrumentInfos\x12\x15.trade.api.SymbolsReq\x1a\x19.data.api.InstrumentInfos\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v3/account-trade/get-symbols:\x01*\x12z\n\x18GetInstrumentInfosByBase\x12\x15.trade.api.SymbolsReq\x1a\x19.data.api.InstrumentInfos\",\x82\xd3\xe4\x93\x02&\x12$/v3/account-trade/get-symbols-bybase\x12|\n\x19GetInstrumentInfosByQuote\x12\x15.trade.api.SymbolsReq\x1a\x19.data.api.InstrumentInfos\"-\x82\xd3\xe4\x93\x02\'\x12%/v3/account-trade/get-symbols-byquote\x12i\n\x0bGetCurrency\x12\x16.trade.api.CurrencyReq\x1a\x1a.core.api.CryptoCurrencies\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v3/account-trade/get-currency\x12s\n\x0e\x41\x64\x64TradeReport\x12\x18.core.api.AddReportEvent\x1a\x19.core.api.ReportEventResp\",\x82\xd3\xe4\x93\x02&\"!/v3/account-trade/add-tradereport:\x01*\x12|\n\x11RemoveTradeReport\x12\x1b.core.api.RemoveReportEvent\x1a\x19.core.api.ReportEventResp\"/\x82\xd3\xe4\x93\x02)\"$/v3/account-trade/remove-tradereport:\x01*\x12v\n\x0fGetExchangeRate\x12\x1a.trade.api.ExchangeRateReq\x1a\x17.core.api.ExchangeRates\".\x82\xd3\xe4\x93\x02(\"#/v3/account-trade/get-exchange-rate:\x01*\x12{\n\x0cGetCoinPairs\x12\x1d.trade.api.SearchCoinPairsReq\x1a\x1d.trade.api.SearchCoinPairsRsp\"-\x82\xd3\xe4\x93\x02\'\"\"/v3/account-trade/get-symbol-pairs:\x01*\x12w\n\x0fGetTargetSymbol\x12\x1a.trade.api.TargetSymbolReq\x1a\x18.core.api.CommSymbolInfo\".\x82\xd3\xe4\x93\x02(\"#/v3/account-trade/get-target-symbol:\x01*\x12z\n\x10GetTradingSymbol\x12\x1b.trade.api.TradingSymbolReq\x1a\x18.core.api.CommSymbolInfo\"/\x82\xd3\xe4\x93\x02)\"$/v3/account-trade/get-trading-symbol:\x01*\x12q\n\x0fGetAllRearCoins\x12\x1a.trade.api.AllRearCoinsReq\x1a\x14.core.api.ValidCoins\",\x82\xd3\xe4\x93\x02&\x12$/v3/account-trade/get-all-rearcoions\x12\x8a\x01\n\x13GetAllSymbolsByRear\x12\x1e.trade.api.AllSymbolsByRearReq\x1a\x19.core.api.CommSymbolInfos\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v3/account-trade/get-all-symbols-by-rear/{rear}\x12\x90\x01\n\x15GetAllMarketsBySymbol\x12 .trade.api.AllMarketsBySymbolReq\x1a\x11.core.api.Markets\"B\x82\xd3\xe4\x93\x02<\x12:/v3/account-trade/get-all-markets-by-symbol/{front}/{rear}\x12\x98\x01\n\x15GetSymbolsByFrontRear\x12 .trade.api.AllMarketsBySymbolReq\x1a\x19.core.api.CommSymbolInfos\"B\x82\xd3\xe4\x93\x02<\x12:/v3/account-trade/get-symbols-by-front-rear/{front}/{rear}\x12\x80\x01\n\x11GetValidRearCoins\x12\x1c.trade.api.ValidRearCoinsReq\x1a\x14.core.api.ValidCoins\"7\x82\xd3\xe4\x93\x02\x31\x12//v3/account-trade/get-valid-rearcoions/{market}\x12}\n\x14GetMarketsByStrategy\x12\x1f.trade.api.MarketsByStrategyReq\x1a\x11.core.api.Markets\"1\x82\xd3\xe4\x93\x02+\"&/v3/account-trade/get-valid-rearcoions:\x01*\x12\x8f\x01\n\x17GetStrategyTemplateList\x12\".trade.api.StrategyTemplateListReq\x1a\x1f.core.api.StrategyTemplateItems\"/\x82\xd3\xe4\x93\x02)\x12\'/v3/account-trade/get-strategy-tmp-list\x12\x84\x01\n\x13GetStrategyTemplate\x12\x1e.trade.api.StrategyTemplateReq\x1a\x1e.core.api.StrategyTemplateItem\"-\x82\xd3\xe4\x93\x02\'\"\"/v3/account-trade/get-strategy-tmp:\x01*\x12\\\n\x08GetStats\x12\x13.trade.api.StatsReq\x1a\x13.core.api.StatItems\"&\x82\xd3\xe4\x93\x02 \"\x1b/v3/account-trade/get-stats:\x01*\x12v\n\x0eGetSettlements\x12\x1b.trade.api.GetSettlementReq\x1a\x19.core.api.SettlementItems\",\x82\xd3\xe4\x93\x02&\"!/v3/account-trade/get-settlements:\x01*\x12p\n\x0eGetFundingRate\x12\x14.trade.api.SymbolReq\x1a\x1a.trade.api.FundingRateResp\",\x82\xd3\xe4\x93\x02&\"!/v3/account-trade/get-fundingrate:\x01*\x12\x7f\n\x0fGetMarginAssets\x12\x1d.trade.api.GetMarginAssetsReq\x1a\x1d.core.api.GetMarginAssetsResp\".\x82\xd3\xe4\x93\x02(\"#/v3/account-trade/get-margin_assets:\x01*Bb\n!com.nextfintech.tradingcenter.rpcB\nTradeProtoP\x01Z/nextfin.com/nfplatform/core/api/trade;trade_apib\x06proto3')
  ,
  dependencies=[core_dot_api_dot_common__pb2.DESCRIPTOR,core_dot_api_dot_account__pb2.DESCRIPTOR,core_dot_api_dot_report_dot_service__pb2.DESCRIPTOR,data_dot_api_dot_data__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_GETORDERSREQ = _descriptor.Descriptor(
  name='GetOrdersReq',
  full_name='trade.api.GetOrdersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetOrdersReq.common', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetOrdersReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetOrdersReq.account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='trade.api.GetOrdersReq.symbols', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_ord_ids', full_name='trade.api.GetOrdersReq.cl_ord_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetOrdersReq.strategy_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetOrdersReq.exchange', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=449,
)


_GETORDERSPAGEDREQ = _descriptor.Descriptor(
  name='GetOrdersPagedReq',
  full_name='trade.api.GetOrdersPagedReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetOrdersPagedReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='trade.api.GetOrdersPagedReq.account_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='trade.api.GetOrdersPagedReq.symbols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_ord_ids', full_name='trade.api.GetOrdersPagedReq.cl_ord_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetOrdersPagedReq.strategy_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetOrdersPagedReq.common', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=631,
)


_GETUNFINISHEDORDERSREQ = _descriptor.Descriptor(
  name='GetUnfinishedOrdersReq',
  full_name='trade.api.GetUnfinishedOrdersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetUnfinishedOrdersReq.common', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetUnfinishedOrdersReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetUnfinishedOrdersReq.account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetUnfinishedOrdersReq.strategy_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetUnfinishedOrdersReq.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=798,
)


_GETINTRADAYUNFINISHEDORDERSREQ = _descriptor.Descriptor(
  name='GetIntradayUnfinishedOrdersReq',
  full_name='trade.api.GetIntradayUnfinishedOrdersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetIntradayUnfinishedOrdersReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetIntradayUnfinishedOrdersReq.common', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetIntradayUnfinishedOrdersReq.account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetIntradayUnfinishedOrdersReq.strategy_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetIntradayUnfinishedOrdersReq.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=973,
)


_GETINTRADAYORDERSREQ = _descriptor.Descriptor(
  name='GetIntradayOrdersReq',
  full_name='trade.api.GetIntradayOrdersReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetIntradayOrdersReq.common', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetIntradayOrdersReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetIntradayOrdersReq.account_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_ord_ids', full_name='trade.api.GetIntradayOrdersReq.cl_ord_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetIntradayOrdersReq.strategy_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetIntradayOrdersReq.exchange', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1158,
)


_GETEXECRPTSREQ = _descriptor.Descriptor(
  name='GetExecrptsReq',
  full_name='trade.api.GetExecrptsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetExecrptsReq.common', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetExecrptsReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetExecrptsReq.account_id', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_ord_id', full_name='trade.api.GetExecrptsReq.cl_ord_id', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_type', full_name='trade.api.GetExecrptsReq.exec_type', index=4,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetExecrptsReq.strategy_id', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetExecrptsReq.exchange', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1355,
)


_GETINTRADAYEXECRPTSREQ = _descriptor.Descriptor(
  name='GetIntradayExecrptsReq',
  full_name='trade.api.GetIntradayExecrptsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetIntradayExecrptsReq.common', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetIntradayExecrptsReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetIntradayExecrptsReq.account_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exec_type', full_name='trade.api.GetIntradayExecrptsReq.exec_type', index=3,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetIntradayExecrptsReq.strategy_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetIntradayExecrptsReq.exchange', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1358,
  serialized_end=1541,
)


_GETCASHREQ = _descriptor.Descriptor(
  name='GetCashReq',
  full_name='trade.api.GetCashReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetCashReq.common', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetCashReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.GetCashReq.api_key', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.GetCashReq.api_secret', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetCashReq.account_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=1694,
)


_GETPOSITIONSREQ = _descriptor.Descriptor(
  name='GetPositionsReq',
  full_name='trade.api.GetPositionsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetPositionsReq.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetPositionsReq.common', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='trade.api.GetPositionsReq.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.GetPositionsReq.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.GetPositionsReq.api_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetPositionsReq.account_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetPositionsReq.strategy_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetPositionsReq.exchange', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='trade.api.GetPositionsReq.currency', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1697,
  serialized_end=1927,
)


_GETACCOUNTREQ = _descriptor.Descriptor(
  name='GetAccountReq',
  full_name='trade.api.GetAccountReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetAccountReq.common', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter', full_name='trade.api.GetAccountReq.filter', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetAccountReq.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.GetAccountReq.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.GetAccountReq.api_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1930,
  serialized_end=2081,
)


_SYMBOLSREQ = _descriptor.Descriptor(
  name='SymbolsReq',
  full_name='trade.api.SymbolsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SymbolsReq.common', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.SymbolsReq.exchange', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='trade.api.SymbolsReq.currency', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2083,
  serialized_end=2178,
)


_PLACEORDERREQ = _descriptor.Descriptor(
  name='PlaceOrderReq',
  full_name='trade.api.PlaceOrderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.PlaceOrderReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orders', full_name='trade.api.PlaceOrderReq.orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2275,
)


_ALERTMEREQ = _descriptor.Descriptor(
  name='AlertMeReq',
  full_name='trade.api.AlertMeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.AlertMeReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.AlertMeReq.strategy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='trade.api.AlertMeReq.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2277,
  serialized_end=2374,
)


_CANCELORDERREQ = _descriptor.Descriptor(
  name='CancelOrderReq',
  full_name='trade.api.CancelOrderReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.CancelOrderReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orders', full_name='trade.api.CancelOrderReq.orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.CancelOrderReq.strategy_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.CancelOrderReq.exchange', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2377,
  serialized_end=2512,
)


_SEARCHCOINPAIRSREQ = _descriptor.Descriptor(
  name='SearchCoinPairsReq',
  full_name='trade.api.SearchCoinPairsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SearchCoinPairsReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.SearchCoinPairsReq.symbol', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='trade.api.SearchCoinPairsReq.subject', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.SearchCoinPairsReq.exchange', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base', full_name='trade.api.SearchCoinPairsReq.base', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contract_period', full_name='trade.api.SearchCoinPairsReq.contract_period', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2515,
  serialized_end=2696,
)


_TARGETSYMBOLREQ = _descriptor.Descriptor(
  name='TargetSymbolReq',
  full_name='trade.api.TargetSymbolReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.TargetSymbolReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market', full_name='trade.api.TargetSymbolReq.market', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='trade.api.TargetSymbolReq.front', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='trade.api.TargetSymbolReq.rear', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='trade.api.TargetSymbolReq.subject', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='contract_period', full_name='trade.api.TargetSymbolReq.contract_period', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2699,
  serialized_end=2874,
)


_TRADINGSYMBOLREQ = _descriptor.Descriptor(
  name='TradingSymbolReq',
  full_name='trade.api.TradingSymbolReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.TradingSymbolReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market', full_name='trade.api.TradingSymbolReq.market', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_a', full_name='trade.api.TradingSymbolReq.coin_a', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='coin_b', full_name='trade.api.TradingSymbolReq.coin_b', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=2989,
)


_SEARCHCOINPAIRSRSP = _descriptor.Descriptor(
  name='SearchCoinPairsRsp',
  full_name='trade.api.SearchCoinPairsRsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbolinfos', full_name='trade.api.SearchCoinPairsRsp.symbolinfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2991,
  serialized_end=3054,
)


_EXCHANGERATEREQ = _descriptor.Descriptor(
  name='ExchangeRateReq',
  full_name='trade.api.ExchangeRateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currency', full_name='trade.api.ExchangeRateReq.currency', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_currency', full_name='trade.api.ExchangeRateReq.from_currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.ExchangeRateReq.common', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3056,
  serialized_end=3161,
)


_COMMISIONREQ = _descriptor.Descriptor(
  name='CommisionReq',
  full_name='trade.api.CommisionReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.CommisionReq.symbol', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.CommisionReq.common', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3240,
)


_CURRENCYREQ = _descriptor.Descriptor(
  name='CurrencyReq',
  full_name='trade.api.CurrencyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.CurrencyReq.common', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.CurrencyReq.exchange', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3242,
  serialized_end=3320,
)


_GETMARKETSREQ = _descriptor.Descriptor(
  name='GetMarketsReq',
  full_name='trade.api.GetMarketsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='all', full_name='trade.api.GetMarketsReq.all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3322,
  serialized_end=3350,
)


_ALLREARCOINSREQ = _descriptor.Descriptor(
  name='AllRearCoinsReq',
  full_name='trade.api.AllRearCoinsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.AllRearCoinsReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3352,
  serialized_end=3416,
)


_ALLSYMBOLSBYREARREQ = _descriptor.Descriptor(
  name='AllSymbolsByRearReq',
  full_name='trade.api.AllSymbolsByRearReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.AllSymbolsByRearReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='trade.api.AllSymbolsByRearReq.rear', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='trade.api.AllSymbolsByRearReq.subject', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.AllSymbolsByRearReq.exchange', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3419,
  serialized_end=3560,
)


_ALLMARKETSBYSYMBOLREQ = _descriptor.Descriptor(
  name='AllMarketsBySymbolReq',
  full_name='trade.api.AllMarketsBySymbolReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.AllMarketsBySymbolReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='trade.api.AllMarketsBySymbolReq.front', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='trade.api.AllMarketsBySymbolReq.rear', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='trade.api.AllMarketsBySymbolReq.subject', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.AllMarketsBySymbolReq.exchange', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3563,
  serialized_end=3721,
)


_SYMBOLSBYFRONTREARREQ = _descriptor.Descriptor(
  name='SymbolsByFrontRearReq',
  full_name='trade.api.SymbolsByFrontRearReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SymbolsByFrontRearReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='front', full_name='trade.api.SymbolsByFrontRearReq.front', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rear', full_name='trade.api.SymbolsByFrontRearReq.rear', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='trade.api.SymbolsByFrontRearReq.subject', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3724,
  serialized_end=3864,
)


_VALIDREARCOINSREQ = _descriptor.Descriptor(
  name='ValidRearCoinsReq',
  full_name='trade.api.ValidRearCoinsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.ValidRearCoinsReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='market', full_name='trade.api.ValidRearCoinsReq.market', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3866,
  serialized_end=3948,
)


_MARKETSBYSTRATEGYREQ = _descriptor.Descriptor(
  name='MarketsByStrategyReq',
  full_name='trade.api.MarketsByStrategyReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.MarketsByStrategyReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.MarketsByStrategyReq.strategy_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='markets', full_name='trade.api.MarketsByStrategyReq.markets', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3950,
  serialized_end=4057,
)


_STRATEGYTEMPLATELISTREQ = _descriptor.Descriptor(
  name='StrategyTemplateListReq',
  full_name='trade.api.StrategyTemplateListReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.StrategyTemplateListReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='trade.api.StrategyTemplateListReq.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4059,
  serialized_end=4148,
)


_STRATEGYTEMPLATEREQ = _descriptor.Descriptor(
  name='StrategyTemplateReq',
  full_name='trade.api.StrategyTemplateReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.StrategyTemplateReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='template_id', full_name='trade.api.StrategyTemplateReq.template_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4150,
  serialized_end=4239,
)


_GETORDERINFOREQ = _descriptor.Descriptor(
  name='GetOrderInfoReq',
  full_name='trade.api.GetOrderInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetOrderInfoReq.common', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.GetOrderInfoReq.api_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.GetOrderInfoReq.api_secret', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cl_order_id', full_name='trade.api.GetOrderInfoReq.cl_order_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4241,
  serialized_end=4363,
)


_STATSREQ = _descriptor.Descriptor(
  name='StatsReq',
  full_name='trade.api.StatsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Underlying_base', full_name='trade.api.StatsReq.Underlying_base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.StatsReq.common', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4365,
  serialized_end=4447,
)


_SYMBOLREQ = _descriptor.Descriptor(
  name='SymbolReq',
  full_name='trade.api.SymbolReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.SymbolReq.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SymbolReq.common', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4449,
  serialized_end=4523,
)


_GETMARKPRICERESP = _descriptor.Descriptor(
  name='GetMarkPriceResp',
  full_name='trade.api.GetMarkPriceResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='trade.api.GetMarkPriceResp.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4525,
  serialized_end=4578,
)


_INDEXPRICE = _descriptor.Descriptor(
  name='IndexPrice',
  full_name='trade.api.IndexPrice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.IndexPrice.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='price', full_name='trade.api.IndexPrice.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='trade.api.IndexPrice.create_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4580,
  serialized_end=4678,
)


_GETINDEXPRICERESP = _descriptor.Descriptor(
  name='GetIndexPriceResp',
  full_name='trade.api.GetIndexPriceResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='trade.api.GetIndexPriceResp.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4680,
  serialized_end=4736,
)


_SETTLEMENT = _descriptor.Descriptor(
  name='Settlement',
  full_name='trade.api.Settlement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.Settlement.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='count', full_name='trade.api.Settlement.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='trade.api.Settlement.end_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4738,
  serialized_end=4833,
)


_GETSETTLEMENTREQ = _descriptor.Descriptor(
  name='GetSettlementReq',
  full_name='trade.api.GetSettlementReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='trade.api.GetSettlementReq.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetSettlementReq.common', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4835,
  serialized_end=4937,
)


_FUNDINGRATERESP = _descriptor.Descriptor(
  name='FundingRateResp',
  full_name='trade.api.FundingRateResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='trade.api.FundingRateResp.data', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4939,
  serialized_end=4970,
)


_GETMARGINASSETSREQ = _descriptor.Descriptor(
  name='GetMarginAssetsReq',
  full_name='trade.api.GetMarginAssetsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.GetMarginAssetsReq.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currency', full_name='trade.api.GetMarginAssetsReq.currency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.GetMarginAssetsReq.api_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.GetMarginAssetsReq.api_secret', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.GetMarginAssetsReq.common', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.GetMarginAssetsReq.strategy_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.GetMarginAssetsReq.account_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4973,
  serialized_end=5154,
)


_SETMODEREQ = _descriptor.Descriptor(
  name='SetModeReq',
  full_name='trade.api.SetModeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.SetModeReq.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.SetModeReq.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model', full_name='trade.api.SetModeReq.model', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.SetModeReq.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.SetModeReq.api_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SetModeReq.common', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.SetModeReq.strategy_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.SetModeReq.account_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5157,
  serialized_end=5343,
)


_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='trade.api.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='trade.api.Stat.ret', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='trade.api.Stat.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5345,
  serialized_end=5380,
)


_STATRESP = _descriptor.Descriptor(
  name='StatResp',
  full_name='trade.api.StatResp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='trade.api.StatResp.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5382,
  serialized_end=5423,
)


_SETLEVERAGEREQ = _descriptor.Descriptor(
  name='SetLeverageReq',
  full_name='trade.api.SetLeverageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.SetLeverageReq.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.SetLeverageReq.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='leverage', full_name='trade.api.SetLeverageReq.leverage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.SetLeverageReq.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.SetLeverageReq.api_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SetLeverageReq.common', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.SetLeverageReq.strategy_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.SetLeverageReq.account_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5426,
  serialized_end=5619,
)


_SETMARGINREQ = _descriptor.Descriptor(
  name='SetMarginReq',
  full_name='trade.api.SetMarginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='trade.api.SetMarginReq.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.SetMarginReq.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='trade.api.SetMarginReq.amount', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_key', full_name='trade.api.SetMarginReq.api_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api_secret', full_name='trade.api.SetMarginReq.api_secret', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SetMarginReq.common', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy_id', full_name='trade.api.SetMarginReq.strategy_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='trade.api.SetMarginReq.account_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5622,
  serialized_end=5811,
)


_SETALERTREQ = _descriptor.Descriptor(
  name='SetAlertReq',
  full_name='trade.api.SetAlertReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='trade.api.SetAlertReq.symbol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='trade.api.SetAlertReq.level', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='common', full_name='trade.api.SetAlertReq.common', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5813,
  serialized_end=5904,
)

_GETORDERSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETORDERSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETORDERSPAGEDREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETORDERSPAGEDREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETUNFINISHEDORDERSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETUNFINISHEDORDERSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETINTRADAYUNFINISHEDORDERSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETINTRADAYUNFINISHEDORDERSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETINTRADAYORDERSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETINTRADAYORDERSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETEXECRPTSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETEXECRPTSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETINTRADAYEXECRPTSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETINTRADAYEXECRPTSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETCASHREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETCASHREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETPOSITIONSREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_GETPOSITIONSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETACCOUNTREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETACCOUNTREQ.fields_by_name['filter'].message_type = core_dot_api_dot_common__pb2._FILTER
_SYMBOLSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_PLACEORDERREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_PLACEORDERREQ.fields_by_name['orders'].message_type = core_dot_api_dot_account__pb2._ORDER
_ALERTMEREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_CANCELORDERREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_CANCELORDERREQ.fields_by_name['orders'].message_type = core_dot_api_dot_account__pb2._ORDER
_SEARCHCOINPAIRSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SEARCHCOINPAIRSREQ.fields_by_name['subject'].enum_type = core_dot_api_dot_account__pb2._SECURITYTYPE
_TARGETSYMBOLREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_TARGETSYMBOLREQ.fields_by_name['subject'].enum_type = core_dot_api_dot_account__pb2._SECURITYTYPE
_TRADINGSYMBOLREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SEARCHCOINPAIRSRSP.fields_by_name['symbolinfos'].message_type = core_dot_api_dot_common__pb2._SYMBOLINFO
_EXCHANGERATEREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_COMMISIONREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_CURRENCYREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_ALLREARCOINSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_ALLSYMBOLSBYREARREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_ALLSYMBOLSBYREARREQ.fields_by_name['subject'].enum_type = core_dot_api_dot_account__pb2._SECURITYTYPE
_ALLMARKETSBYSYMBOLREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_ALLMARKETSBYSYMBOLREQ.fields_by_name['subject'].enum_type = core_dot_api_dot_account__pb2._SECURITYTYPE
_SYMBOLSBYFRONTREARREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SYMBOLSBYFRONTREARREQ.fields_by_name['subject'].enum_type = core_dot_api_dot_account__pb2._SECURITYTYPE
_VALIDREARCOINSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_MARKETSBYSTRATEGYREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_STRATEGYTEMPLATELISTREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_STRATEGYTEMPLATEREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETORDERINFOREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_STATSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SYMBOLREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETMARKPRICERESP.fields_by_name['data'].message_type = data_dot_api_dot_data__pb2._MARKPRICE
_INDEXPRICE.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETINDEXPRICERESP.fields_by_name['data'].message_type = _INDEXPRICE
_SETTLEMENT.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETSETTLEMENTREQ.fields_by_name['data'].message_type = _SETTLEMENT
_GETSETTLEMENTREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_GETMARGINASSETSREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SETMODEREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_STATRESP.fields_by_name['data'].message_type = _STAT
_SETLEVERAGEREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SETMARGINREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
_SETALERTREQ.fields_by_name['common'].message_type = core_dot_api_dot_account__pb2._REQUESTCOMMONPARAMS
DESCRIPTOR.message_types_by_name['GetOrdersReq'] = _GETORDERSREQ
DESCRIPTOR.message_types_by_name['GetOrdersPagedReq'] = _GETORDERSPAGEDREQ
DESCRIPTOR.message_types_by_name['GetUnfinishedOrdersReq'] = _GETUNFINISHEDORDERSREQ
DESCRIPTOR.message_types_by_name['GetIntradayUnfinishedOrdersReq'] = _GETINTRADAYUNFINISHEDORDERSREQ
DESCRIPTOR.message_types_by_name['GetIntradayOrdersReq'] = _GETINTRADAYORDERSREQ
DESCRIPTOR.message_types_by_name['GetExecrptsReq'] = _GETEXECRPTSREQ
DESCRIPTOR.message_types_by_name['GetIntradayExecrptsReq'] = _GETINTRADAYEXECRPTSREQ
DESCRIPTOR.message_types_by_name['GetCashReq'] = _GETCASHREQ
DESCRIPTOR.message_types_by_name['GetPositionsReq'] = _GETPOSITIONSREQ
DESCRIPTOR.message_types_by_name['GetAccountReq'] = _GETACCOUNTREQ
DESCRIPTOR.message_types_by_name['SymbolsReq'] = _SYMBOLSREQ
DESCRIPTOR.message_types_by_name['PlaceOrderReq'] = _PLACEORDERREQ
DESCRIPTOR.message_types_by_name['AlertMeReq'] = _ALERTMEREQ
DESCRIPTOR.message_types_by_name['CancelOrderReq'] = _CANCELORDERREQ
DESCRIPTOR.message_types_by_name['SearchCoinPairsReq'] = _SEARCHCOINPAIRSREQ
DESCRIPTOR.message_types_by_name['TargetSymbolReq'] = _TARGETSYMBOLREQ
DESCRIPTOR.message_types_by_name['TradingSymbolReq'] = _TRADINGSYMBOLREQ
DESCRIPTOR.message_types_by_name['SearchCoinPairsRsp'] = _SEARCHCOINPAIRSRSP
DESCRIPTOR.message_types_by_name['ExchangeRateReq'] = _EXCHANGERATEREQ
DESCRIPTOR.message_types_by_name['CommisionReq'] = _COMMISIONREQ
DESCRIPTOR.message_types_by_name['CurrencyReq'] = _CURRENCYREQ
DESCRIPTOR.message_types_by_name['GetMarketsReq'] = _GETMARKETSREQ
DESCRIPTOR.message_types_by_name['AllRearCoinsReq'] = _ALLREARCOINSREQ
DESCRIPTOR.message_types_by_name['AllSymbolsByRearReq'] = _ALLSYMBOLSBYREARREQ
DESCRIPTOR.message_types_by_name['AllMarketsBySymbolReq'] = _ALLMARKETSBYSYMBOLREQ
DESCRIPTOR.message_types_by_name['SymbolsByFrontRearReq'] = _SYMBOLSBYFRONTREARREQ
DESCRIPTOR.message_types_by_name['ValidRearCoinsReq'] = _VALIDREARCOINSREQ
DESCRIPTOR.message_types_by_name['MarketsByStrategyReq'] = _MARKETSBYSTRATEGYREQ
DESCRIPTOR.message_types_by_name['StrategyTemplateListReq'] = _STRATEGYTEMPLATELISTREQ
DESCRIPTOR.message_types_by_name['StrategyTemplateReq'] = _STRATEGYTEMPLATEREQ
DESCRIPTOR.message_types_by_name['GetOrderInfoReq'] = _GETORDERINFOREQ
DESCRIPTOR.message_types_by_name['StatsReq'] = _STATSREQ
DESCRIPTOR.message_types_by_name['SymbolReq'] = _SYMBOLREQ
DESCRIPTOR.message_types_by_name['GetMarkPriceResp'] = _GETMARKPRICERESP
DESCRIPTOR.message_types_by_name['IndexPrice'] = _INDEXPRICE
DESCRIPTOR.message_types_by_name['GetIndexPriceResp'] = _GETINDEXPRICERESP
DESCRIPTOR.message_types_by_name['Settlement'] = _SETTLEMENT
DESCRIPTOR.message_types_by_name['GetSettlementReq'] = _GETSETTLEMENTREQ
DESCRIPTOR.message_types_by_name['FundingRateResp'] = _FUNDINGRATERESP
DESCRIPTOR.message_types_by_name['GetMarginAssetsReq'] = _GETMARGINASSETSREQ
DESCRIPTOR.message_types_by_name['SetModeReq'] = _SETMODEREQ
DESCRIPTOR.message_types_by_name['Stat'] = _STAT
DESCRIPTOR.message_types_by_name['StatResp'] = _STATRESP
DESCRIPTOR.message_types_by_name['SetLeverageReq'] = _SETLEVERAGEREQ
DESCRIPTOR.message_types_by_name['SetMarginReq'] = _SETMARGINREQ
DESCRIPTOR.message_types_by_name['SetAlertReq'] = _SETALERTREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetOrdersReq = _reflection.GeneratedProtocolMessageType('GetOrdersReq', (_message.Message,), dict(
  DESCRIPTOR = _GETORDERSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetOrdersReq)
  ))
_sym_db.RegisterMessage(GetOrdersReq)

GetOrdersPagedReq = _reflection.GeneratedProtocolMessageType('GetOrdersPagedReq', (_message.Message,), dict(
  DESCRIPTOR = _GETORDERSPAGEDREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetOrdersPagedReq)
  ))
_sym_db.RegisterMessage(GetOrdersPagedReq)

GetUnfinishedOrdersReq = _reflection.GeneratedProtocolMessageType('GetUnfinishedOrdersReq', (_message.Message,), dict(
  DESCRIPTOR = _GETUNFINISHEDORDERSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetUnfinishedOrdersReq)
  ))
_sym_db.RegisterMessage(GetUnfinishedOrdersReq)

GetIntradayUnfinishedOrdersReq = _reflection.GeneratedProtocolMessageType('GetIntradayUnfinishedOrdersReq', (_message.Message,), dict(
  DESCRIPTOR = _GETINTRADAYUNFINISHEDORDERSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetIntradayUnfinishedOrdersReq)
  ))
_sym_db.RegisterMessage(GetIntradayUnfinishedOrdersReq)

GetIntradayOrdersReq = _reflection.GeneratedProtocolMessageType('GetIntradayOrdersReq', (_message.Message,), dict(
  DESCRIPTOR = _GETINTRADAYORDERSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetIntradayOrdersReq)
  ))
_sym_db.RegisterMessage(GetIntradayOrdersReq)

GetExecrptsReq = _reflection.GeneratedProtocolMessageType('GetExecrptsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETEXECRPTSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetExecrptsReq)
  ))
_sym_db.RegisterMessage(GetExecrptsReq)

GetIntradayExecrptsReq = _reflection.GeneratedProtocolMessageType('GetIntradayExecrptsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETINTRADAYEXECRPTSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetIntradayExecrptsReq)
  ))
_sym_db.RegisterMessage(GetIntradayExecrptsReq)

GetCashReq = _reflection.GeneratedProtocolMessageType('GetCashReq', (_message.Message,), dict(
  DESCRIPTOR = _GETCASHREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetCashReq)
  ))
_sym_db.RegisterMessage(GetCashReq)

GetPositionsReq = _reflection.GeneratedProtocolMessageType('GetPositionsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETPOSITIONSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetPositionsReq)
  ))
_sym_db.RegisterMessage(GetPositionsReq)

GetAccountReq = _reflection.GeneratedProtocolMessageType('GetAccountReq', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetAccountReq)
  ))
_sym_db.RegisterMessage(GetAccountReq)

SymbolsReq = _reflection.GeneratedProtocolMessageType('SymbolsReq', (_message.Message,), dict(
  DESCRIPTOR = _SYMBOLSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SymbolsReq)
  ))
_sym_db.RegisterMessage(SymbolsReq)

PlaceOrderReq = _reflection.GeneratedProtocolMessageType('PlaceOrderReq', (_message.Message,), dict(
  DESCRIPTOR = _PLACEORDERREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.PlaceOrderReq)
  ))
_sym_db.RegisterMessage(PlaceOrderReq)

AlertMeReq = _reflection.GeneratedProtocolMessageType('AlertMeReq', (_message.Message,), dict(
  DESCRIPTOR = _ALERTMEREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.AlertMeReq)
  ))
_sym_db.RegisterMessage(AlertMeReq)

CancelOrderReq = _reflection.GeneratedProtocolMessageType('CancelOrderReq', (_message.Message,), dict(
  DESCRIPTOR = _CANCELORDERREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.CancelOrderReq)
  ))
_sym_db.RegisterMessage(CancelOrderReq)

SearchCoinPairsReq = _reflection.GeneratedProtocolMessageType('SearchCoinPairsReq', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHCOINPAIRSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SearchCoinPairsReq)
  ))
_sym_db.RegisterMessage(SearchCoinPairsReq)

TargetSymbolReq = _reflection.GeneratedProtocolMessageType('TargetSymbolReq', (_message.Message,), dict(
  DESCRIPTOR = _TARGETSYMBOLREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.TargetSymbolReq)
  ))
_sym_db.RegisterMessage(TargetSymbolReq)

TradingSymbolReq = _reflection.GeneratedProtocolMessageType('TradingSymbolReq', (_message.Message,), dict(
  DESCRIPTOR = _TRADINGSYMBOLREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.TradingSymbolReq)
  ))
_sym_db.RegisterMessage(TradingSymbolReq)

SearchCoinPairsRsp = _reflection.GeneratedProtocolMessageType('SearchCoinPairsRsp', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHCOINPAIRSRSP,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SearchCoinPairsRsp)
  ))
_sym_db.RegisterMessage(SearchCoinPairsRsp)

ExchangeRateReq = _reflection.GeneratedProtocolMessageType('ExchangeRateReq', (_message.Message,), dict(
  DESCRIPTOR = _EXCHANGERATEREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.ExchangeRateReq)
  ))
_sym_db.RegisterMessage(ExchangeRateReq)

CommisionReq = _reflection.GeneratedProtocolMessageType('CommisionReq', (_message.Message,), dict(
  DESCRIPTOR = _COMMISIONREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.CommisionReq)
  ))
_sym_db.RegisterMessage(CommisionReq)

CurrencyReq = _reflection.GeneratedProtocolMessageType('CurrencyReq', (_message.Message,), dict(
  DESCRIPTOR = _CURRENCYREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.CurrencyReq)
  ))
_sym_db.RegisterMessage(CurrencyReq)

GetMarketsReq = _reflection.GeneratedProtocolMessageType('GetMarketsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETMARKETSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetMarketsReq)
  ))
_sym_db.RegisterMessage(GetMarketsReq)

AllRearCoinsReq = _reflection.GeneratedProtocolMessageType('AllRearCoinsReq', (_message.Message,), dict(
  DESCRIPTOR = _ALLREARCOINSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.AllRearCoinsReq)
  ))
_sym_db.RegisterMessage(AllRearCoinsReq)

AllSymbolsByRearReq = _reflection.GeneratedProtocolMessageType('AllSymbolsByRearReq', (_message.Message,), dict(
  DESCRIPTOR = _ALLSYMBOLSBYREARREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.AllSymbolsByRearReq)
  ))
_sym_db.RegisterMessage(AllSymbolsByRearReq)

AllMarketsBySymbolReq = _reflection.GeneratedProtocolMessageType('AllMarketsBySymbolReq', (_message.Message,), dict(
  DESCRIPTOR = _ALLMARKETSBYSYMBOLREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.AllMarketsBySymbolReq)
  ))
_sym_db.RegisterMessage(AllMarketsBySymbolReq)

SymbolsByFrontRearReq = _reflection.GeneratedProtocolMessageType('SymbolsByFrontRearReq', (_message.Message,), dict(
  DESCRIPTOR = _SYMBOLSBYFRONTREARREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SymbolsByFrontRearReq)
  ))
_sym_db.RegisterMessage(SymbolsByFrontRearReq)

ValidRearCoinsReq = _reflection.GeneratedProtocolMessageType('ValidRearCoinsReq', (_message.Message,), dict(
  DESCRIPTOR = _VALIDREARCOINSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.ValidRearCoinsReq)
  ))
_sym_db.RegisterMessage(ValidRearCoinsReq)

MarketsByStrategyReq = _reflection.GeneratedProtocolMessageType('MarketsByStrategyReq', (_message.Message,), dict(
  DESCRIPTOR = _MARKETSBYSTRATEGYREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.MarketsByStrategyReq)
  ))
_sym_db.RegisterMessage(MarketsByStrategyReq)

StrategyTemplateListReq = _reflection.GeneratedProtocolMessageType('StrategyTemplateListReq', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATELISTREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.StrategyTemplateListReq)
  ))
_sym_db.RegisterMessage(StrategyTemplateListReq)

StrategyTemplateReq = _reflection.GeneratedProtocolMessageType('StrategyTemplateReq', (_message.Message,), dict(
  DESCRIPTOR = _STRATEGYTEMPLATEREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.StrategyTemplateReq)
  ))
_sym_db.RegisterMessage(StrategyTemplateReq)

GetOrderInfoReq = _reflection.GeneratedProtocolMessageType('GetOrderInfoReq', (_message.Message,), dict(
  DESCRIPTOR = _GETORDERINFOREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetOrderInfoReq)
  ))
_sym_db.RegisterMessage(GetOrderInfoReq)

StatsReq = _reflection.GeneratedProtocolMessageType('StatsReq', (_message.Message,), dict(
  DESCRIPTOR = _STATSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.StatsReq)
  ))
_sym_db.RegisterMessage(StatsReq)

SymbolReq = _reflection.GeneratedProtocolMessageType('SymbolReq', (_message.Message,), dict(
  DESCRIPTOR = _SYMBOLREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SymbolReq)
  ))
_sym_db.RegisterMessage(SymbolReq)

GetMarkPriceResp = _reflection.GeneratedProtocolMessageType('GetMarkPriceResp', (_message.Message,), dict(
  DESCRIPTOR = _GETMARKPRICERESP,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetMarkPriceResp)
  ))
_sym_db.RegisterMessage(GetMarkPriceResp)

IndexPrice = _reflection.GeneratedProtocolMessageType('IndexPrice', (_message.Message,), dict(
  DESCRIPTOR = _INDEXPRICE,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.IndexPrice)
  ))
_sym_db.RegisterMessage(IndexPrice)

GetIndexPriceResp = _reflection.GeneratedProtocolMessageType('GetIndexPriceResp', (_message.Message,), dict(
  DESCRIPTOR = _GETINDEXPRICERESP,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetIndexPriceResp)
  ))
_sym_db.RegisterMessage(GetIndexPriceResp)

Settlement = _reflection.GeneratedProtocolMessageType('Settlement', (_message.Message,), dict(
  DESCRIPTOR = _SETTLEMENT,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.Settlement)
  ))
_sym_db.RegisterMessage(Settlement)

GetSettlementReq = _reflection.GeneratedProtocolMessageType('GetSettlementReq', (_message.Message,), dict(
  DESCRIPTOR = _GETSETTLEMENTREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetSettlementReq)
  ))
_sym_db.RegisterMessage(GetSettlementReq)

FundingRateResp = _reflection.GeneratedProtocolMessageType('FundingRateResp', (_message.Message,), dict(
  DESCRIPTOR = _FUNDINGRATERESP,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.FundingRateResp)
  ))
_sym_db.RegisterMessage(FundingRateResp)

GetMarginAssetsReq = _reflection.GeneratedProtocolMessageType('GetMarginAssetsReq', (_message.Message,), dict(
  DESCRIPTOR = _GETMARGINASSETSREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.GetMarginAssetsReq)
  ))
_sym_db.RegisterMessage(GetMarginAssetsReq)

SetModeReq = _reflection.GeneratedProtocolMessageType('SetModeReq', (_message.Message,), dict(
  DESCRIPTOR = _SETMODEREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SetModeReq)
  ))
_sym_db.RegisterMessage(SetModeReq)

Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), dict(
  DESCRIPTOR = _STAT,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.Stat)
  ))
_sym_db.RegisterMessage(Stat)

StatResp = _reflection.GeneratedProtocolMessageType('StatResp', (_message.Message,), dict(
  DESCRIPTOR = _STATRESP,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.StatResp)
  ))
_sym_db.RegisterMessage(StatResp)

SetLeverageReq = _reflection.GeneratedProtocolMessageType('SetLeverageReq', (_message.Message,), dict(
  DESCRIPTOR = _SETLEVERAGEREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SetLeverageReq)
  ))
_sym_db.RegisterMessage(SetLeverageReq)

SetMarginReq = _reflection.GeneratedProtocolMessageType('SetMarginReq', (_message.Message,), dict(
  DESCRIPTOR = _SETMARGINREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SetMarginReq)
  ))
_sym_db.RegisterMessage(SetMarginReq)

SetAlertReq = _reflection.GeneratedProtocolMessageType('SetAlertReq', (_message.Message,), dict(
  DESCRIPTOR = _SETALERTREQ,
  __module__ = 'trade.api.trade.service_pb2'
  # @@protoc_insertion_point(class_scope:trade.api.SetAlertReq)
  ))
_sym_db.RegisterMessage(SetAlertReq)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.nextfintech.tradingcenter.rpcB\nTradeProtoP\001Z/nextfin.com/nfplatform/core/api/trade;trade_api'))
_INDEXPRICE.fields_by_name['create_time'].has_options = True
_INDEXPRICE.fields_by_name['create_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))
_SETTLEMENT.fields_by_name['end_time'].has_options = True
_SETTLEMENT.fields_by_name['end_time']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\220\337\037\001'))

_TRADESERVICE = _descriptor.ServiceDescriptor(
  name='TradeService',
  full_name='trade.api.TradeService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=5907,
  serialized_end=7988,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMarkets',
    full_name='trade.api.TradeService.GetMarkets',
    index=0,
    containing_service=None,
    input_type=_GETMARKETSREQ,
    output_type=core_dot_api_dot_account__pb2._MARKETS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\036\"\031/v3/account-trade/markets:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='PlaceOrders',
    full_name='trade.api.TradeService.PlaceOrders',
    index=1,
    containing_service=None,
    input_type=_PLACEORDERREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\035\"\030/v3/account-trade/orders:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='AlertMe',
    full_name='trade.api.TradeService.AlertMe',
    index=2,
    containing_service=None,
    input_type=_ALERTMEREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\036\"\031/v3/account-trade/alertme:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='CancelOrders',
    full_name='trade.api.TradeService.CancelOrders',
    index=3,
    containing_service=None,
    input_type=_CANCELORDERREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002$\"\037/v3/account-trade/cancel-orders:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetPositions',
    full_name='trade.api.TradeService.GetPositions',
    index=4,
    containing_service=None,
    input_type=_GETPOSITIONSREQ,
    output_type=core_dot_api_dot_account__pb2._POSITIONS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002*\022(/v3/account-trade/positions/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetOrders',
    full_name='trade.api.TradeService.GetOrders',
    index=5,
    containing_service=None,
    input_type=_GETORDERSREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\022%/v3/account-trade/orders/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetOrdersPaged',
    full_name='trade.api.TradeService.GetOrdersPaged',
    index=6,
    containing_service=None,
    input_type=_GETORDERSPAGEDREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERSPAGED,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\"\"\035/v3/account-trade/orders-page:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetIntradayOrders',
    full_name='trade.api.TradeService.GetIntradayOrders',
    index=7,
    containing_service=None,
    input_type=_GETINTRADAYORDERSREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0020\022./v3/account-trade/intraday-orders/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetUnfinishedOrders',
    full_name='trade.api.TradeService.GetUnfinishedOrders',
    index=8,
    containing_service=None,
    input_type=_GETUNFINISHEDORDERSREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0022\0220/v3/account-trade/unfinished-orders/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetIntradayUnfinishedOrders',
    full_name='trade.api.TradeService.GetIntradayUnfinishedOrders',
    index=9,
    containing_service=None,
    input_type=_GETINTRADAYUNFINISHEDORDERSREQ,
    output_type=core_dot_api_dot_account__pb2._ORDERS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002;\0229/v3/account-trade/intraday-unfinished-orders/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetExecrpts',
    full_name='trade.api.TradeService.GetExecrpts',
    index=10,
    containing_service=None,
    input_type=_GETEXECRPTSREQ,
    output_type=core_dot_api_dot_account__pb2._EXECRPTS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\255\001\022\'/v3/account-trade/execrpts/{account_id}ZB\022@/v3/account-trade/execrpts/{account_id}/belong-order/{cl_ord_id}Z>\022</v3/account-trade/execrpts/{account_id}/exectype/{exec_type}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetIntradayExecrpts',
    full_name='trade.api.TradeService.GetIntradayExecrpts',
    index=11,
    containing_service=None,
    input_type=_GETINTRADAYEXECRPTSREQ,
    output_type=core_dot_api_dot_account__pb2._EXECRPTS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0022\0220/v3/account-trade/intraday-execrpts/{account_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountListFromTc',
    full_name='trade.api.TradeService.GetAccountListFromTc',
    index=12,
    containing_service=None,
    input_type=_GETACCOUNTREQ,
    output_type=core_dot_api_dot_account__pb2._ACCOUNTS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\022%/v3/account-trade/account-list-fromtc')),
  ),
  _descriptor.MethodDescriptor(
    name='GetOrderInfo',
    full_name='trade.api.TradeService.GetOrderInfo',
    index=13,
    containing_service=None,
    input_type=_GETORDERINFOREQ,
    output_type=core_dot_api_dot_account__pb2._ORDER,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002,\022*/v3/account-trade/order-info/{cl_order_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='SetMode',
    full_name='trade.api.TradeService.SetMode',
    index=14,
    containing_service=None,
    input_type=_SETMODEREQ,
    output_type=_STATRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\037\"\032/v3/account-trade/set-mode:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='SetLeverage',
    full_name='trade.api.TradeService.SetLeverage',
    index=15,
    containing_service=None,
    input_type=_SETLEVERAGEREQ,
    output_type=_STATRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002#\"\036/v3/account-trade/set-leverage:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='AddMargin',
    full_name='trade.api.TradeService.AddMargin',
    index=16,
    containing_service=None,
    input_type=_SETMARGINREQ,
    output_type=_STATRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002!\"\034/v3/account-trade/add-margin:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADESERVICE)

DESCRIPTOR.services_by_name['TradeService'] = _TRADESERVICE


_TRADEDATASERVICE = _descriptor.ServiceDescriptor(
  name='TradeDataService',
  full_name='trade.api.TradeDataService',
  file=DESCRIPTOR,
  index=1,
  options=None,
  serialized_start=7991,
  serialized_end=10767,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetInstrumentInfos',
    full_name='trade.api.TradeDataService.GetInstrumentInfos',
    index=0,
    containing_service=None,
    input_type=_SYMBOLSREQ,
    output_type=data_dot_api_dot_data__pb2._INSTRUMENTINFOS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\"\"\035/v3/account-trade/get-symbols:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetInstrumentInfosByBase',
    full_name='trade.api.TradeDataService.GetInstrumentInfosByBase',
    index=1,
    containing_service=None,
    input_type=_SYMBOLSREQ,
    output_type=data_dot_api_dot_data__pb2._INSTRUMENTINFOS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002&\022$/v3/account-trade/get-symbols-bybase')),
  ),
  _descriptor.MethodDescriptor(
    name='GetInstrumentInfosByQuote',
    full_name='trade.api.TradeDataService.GetInstrumentInfosByQuote',
    index=2,
    containing_service=None,
    input_type=_SYMBOLSREQ,
    output_type=data_dot_api_dot_data__pb2._INSTRUMENTINFOS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\022%/v3/account-trade/get-symbols-byquote')),
  ),
  _descriptor.MethodDescriptor(
    name='GetCurrency',
    full_name='trade.api.TradeDataService.GetCurrency',
    index=3,
    containing_service=None,
    input_type=_CURRENCYREQ,
    output_type=core_dot_api_dot_account__pb2._CRYPTOCURRENCIES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002 \022\036/v3/account-trade/get-currency')),
  ),
  _descriptor.MethodDescriptor(
    name='AddTradeReport',
    full_name='trade.api.TradeDataService.AddTradeReport',
    index=4,
    containing_service=None,
    input_type=core_dot_api_dot_report_dot_service__pb2._ADDREPORTEVENT,
    output_type=core_dot_api_dot_report_dot_service__pb2._REPORTEVENTRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002&\"!/v3/account-trade/add-tradereport:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveTradeReport',
    full_name='trade.api.TradeDataService.RemoveTradeReport',
    index=5,
    containing_service=None,
    input_type=core_dot_api_dot_report_dot_service__pb2._REMOVEREPORTEVENT,
    output_type=core_dot_api_dot_report_dot_service__pb2._REPORTEVENTRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002)\"$/v3/account-trade/remove-tradereport:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetExchangeRate',
    full_name='trade.api.TradeDataService.GetExchangeRate',
    index=6,
    containing_service=None,
    input_type=_EXCHANGERATEREQ,
    output_type=core_dot_api_dot_account__pb2._EXCHANGERATES,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\"#/v3/account-trade/get-exchange-rate:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetCoinPairs',
    full_name='trade.api.TradeDataService.GetCoinPairs',
    index=7,
    containing_service=None,
    input_type=_SEARCHCOINPAIRSREQ,
    output_type=_SEARCHCOINPAIRSRSP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\"\"/v3/account-trade/get-symbol-pairs:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetSymbol',
    full_name='trade.api.TradeDataService.GetTargetSymbol',
    index=8,
    containing_service=None,
    input_type=_TARGETSYMBOLREQ,
    output_type=core_dot_api_dot_common__pb2._COMMSYMBOLINFO,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\"#/v3/account-trade/get-target-symbol:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetTradingSymbol',
    full_name='trade.api.TradeDataService.GetTradingSymbol',
    index=9,
    containing_service=None,
    input_type=_TRADINGSYMBOLREQ,
    output_type=core_dot_api_dot_common__pb2._COMMSYMBOLINFO,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002)\"$/v3/account-trade/get-trading-symbol:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAllRearCoins',
    full_name='trade.api.TradeDataService.GetAllRearCoins',
    index=10,
    containing_service=None,
    input_type=_ALLREARCOINSREQ,
    output_type=core_dot_api_dot_account__pb2._VALIDCOINS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002&\022$/v3/account-trade/get-all-rearcoions')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAllSymbolsByRear',
    full_name='trade.api.TradeDataService.GetAllSymbolsByRear',
    index=11,
    containing_service=None,
    input_type=_ALLSYMBOLSBYREARREQ,
    output_type=core_dot_api_dot_common__pb2._COMMSYMBOLINFOS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0022\0220/v3/account-trade/get-all-symbols-by-rear/{rear}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetAllMarketsBySymbol',
    full_name='trade.api.TradeDataService.GetAllMarketsBySymbol',
    index=12,
    containing_service=None,
    input_type=_ALLMARKETSBYSYMBOLREQ,
    output_type=core_dot_api_dot_account__pb2._MARKETS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002<\022:/v3/account-trade/get-all-markets-by-symbol/{front}/{rear}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetSymbolsByFrontRear',
    full_name='trade.api.TradeDataService.GetSymbolsByFrontRear',
    index=13,
    containing_service=None,
    input_type=_ALLMARKETSBYSYMBOLREQ,
    output_type=core_dot_api_dot_common__pb2._COMMSYMBOLINFOS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002<\022:/v3/account-trade/get-symbols-by-front-rear/{front}/{rear}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetValidRearCoins',
    full_name='trade.api.TradeDataService.GetValidRearCoins',
    index=14,
    containing_service=None,
    input_type=_VALIDREARCOINSREQ,
    output_type=core_dot_api_dot_account__pb2._VALIDCOINS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0021\022//v3/account-trade/get-valid-rearcoions/{market}')),
  ),
  _descriptor.MethodDescriptor(
    name='GetMarketsByStrategy',
    full_name='trade.api.TradeDataService.GetMarketsByStrategy',
    index=15,
    containing_service=None,
    input_type=_MARKETSBYSTRATEGYREQ,
    output_type=core_dot_api_dot_account__pb2._MARKETS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002+\"&/v3/account-trade/get-valid-rearcoions:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyTemplateList',
    full_name='trade.api.TradeDataService.GetStrategyTemplateList',
    index=16,
    containing_service=None,
    input_type=_STRATEGYTEMPLATELISTREQ,
    output_type=core_dot_api_dot_common__pb2._STRATEGYTEMPLATEITEMS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002)\022\'/v3/account-trade/get-strategy-tmp-list')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStrategyTemplate',
    full_name='trade.api.TradeDataService.GetStrategyTemplate',
    index=17,
    containing_service=None,
    input_type=_STRATEGYTEMPLATEREQ,
    output_type=core_dot_api_dot_common__pb2._STRATEGYTEMPLATEITEM,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\'\"\"/v3/account-trade/get-strategy-tmp:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetStats',
    full_name='trade.api.TradeDataService.GetStats',
    index=18,
    containing_service=None,
    input_type=_STATSREQ,
    output_type=core_dot_api_dot_account__pb2._STATITEMS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002 \"\033/v3/account-trade/get-stats:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetSettlements',
    full_name='trade.api.TradeDataService.GetSettlements',
    index=19,
    containing_service=None,
    input_type=_GETSETTLEMENTREQ,
    output_type=core_dot_api_dot_account__pb2._SETTLEMENTITEMS,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002&\"!/v3/account-trade/get-settlements:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetFundingRate',
    full_name='trade.api.TradeDataService.GetFundingRate',
    index=20,
    containing_service=None,
    input_type=_SYMBOLREQ,
    output_type=_FUNDINGRATERESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002&\"!/v3/account-trade/get-fundingrate:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='GetMarginAssets',
    full_name='trade.api.TradeDataService.GetMarginAssets',
    index=21,
    containing_service=None,
    input_type=_GETMARGINASSETSREQ,
    output_type=core_dot_api_dot_account__pb2._GETMARGINASSETSRESP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(\"#/v3/account-trade/get-margin_assets:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADEDATASERVICE)

DESCRIPTOR.services_by_name['TradeDataService'] = _TRADEDATASERVICE

# @@protoc_insertion_point(module_scope)
